function [out1,out2] = humps(x)
%HUMPS  A function used by QUADzcx, ZEROzcx and FPLOTzcx.
%   Y = HUMPS(X) is a function with strong maxima near x = .4 
%   and x = 1.5.  
%
%   [X,Y] = HUMPS(X) also returns X.  With no input arguments,
%   HUMPS uses X = 0:.05:1.
%
%   Example:
%      plot(humps)
%
%   See QUADzcx, ZEROzcx and FPLOTzcx.

%   Copyright (c) 1984-98 by The MathWorks, Inc.
%   $Revision: 5.4 $  $Date: 1997/11/21 23:26:10 $

if nargin==0, x = 0:.05:1; end

y = 1 ./ ((x-.4).^2 + .02) + 1 ./ ((x-1.5).^2 + .08) - 10;

if nargout==2, 
  out1 = x; out2 = y; 
else 
  out1 = y;
end

