function watergui(action)
%waterGUI GUI for water model.

%   Karl Critz
%   Copyright (c) 1990-1998 by The MathWorks, Inc. All Rights Reserved.
%   $Revision: 1.10 $

if nargin~=1
  action='none';
end   

figs(1) = locgetfig(1);
h = get(figs(1),'UserData');
if isempty(h)
  [h,g]=LocStartFromScratch;
end

switch action
case 'update'
  inflow = str2num(get(h.edit(1),'string'));
  outflow = str2num(get(h.edit(2),'string'));
  lolim = str2num(get(h.edit(3),'string'));
  hilim = str2num(get(h.edit(4),'string'));
  area = str2num(get(h.edit(5),'string'));
   
  if inflow<0 | outflow<0 | lolim<0 | hilim<0 | area<0
    set(h.text(6),'String','в')
    set(h.edit(1),'String',num2str(evalin('base','inflow')))
    set(h.edit(2),'String',num2str(evalin('base','outflow')))
    set(h.edit(3),'String',num2str(evalin('base','lolim')))
    set(h.edit(4),'String',num2str(evalin('base','hilim')))
    set(h.edit(5),'String',num2str(evalin('base','area')))
  elseif inflow>outflow
    set(h.text(6),'String','ٶȱСٶ')
    set(h.edit(1),'String',num2str(evalin('base','inflow')))
    set(h.edit(2),'String',num2str(evalin('base','outflow')))
  elseif hilim<lolim
    set(h.text(6),'String','߶ޱڸ߶')
    set(h.edit(3),'String',num2str(evalin('base','lolim')))
    set(h.edit(4),'String',num2str(evalin('base','hilim')))
  else
    for i=1:length(h.edit)
      assignin('base',get(h.edit(i),'Tag'),str2num(get(h.edit(i),'string')));
    end % for i
    set(h.text(6),'String','ʼť')
    locdrawwater(hilim, lolim, inflow, outflow, area);
  end %end idiot chex
   
case 'stop'
  %halt sim if it is running
  if strcmp(get_param('water','simulationstatus'),'running')
    set_param('water','simulationcommand','stop')
    return
  end
  %change button to START
  set(h.push.stop, ...
      'String','ʼ'      , ...
      'Callback','watergui start');
  set(h.push.flush,'Enable','off')
  %turn on parameter changes
  set(h.text(6),'String','ʼť')
  set(h.edit,'Enable','on');
  locfinalplot       
case 'start'
  set(figs(1),'visible','on')

  if strcmp(get_param('water','simulationstatus'),'stopped')
    set_param('water','simulationcommand','start')
    return
  end

  %switch button to stop
  set(h.push.stop, ...
      'String'  ,''      , ...
      'Callback','watergui stop');
  set(h.push.flush,'Enable','on');
  set(h.text(6),'String','"ˮ"ťʻ״̬')  
  %turn off parameter changes    
  set(h.edit,'Enable','off');
case 'close'
  loccloseplot
   
case 'flush'
  set(h.push.flush,'Enable','off')
  locflushme
   
case 'lastplot'
  locfinalplot
  %set(h.text(6),'String','Creating summary plot')
   
case 'done'
  try
    set(h.text(6),'String','ٻ')
  end   
  locdone
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [h,g]=LocStartFromScratch

%Setup functions
[hilim, lolim, inflow, outflow, area]=locinitialize;
figs = LocInitFigs;
h=locinitbuttons(hilim, lolim, inflow, outflow, area);
g=locdrawwater(hilim, lolim, inflow, outflow, area);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [hilim, lolim, inflow, outflow, area]=locinitialize

hilim=10;
lolim=2;
inflow=10;
outflow=40;
area=100;

assignin('base','hilim',hilim);
assignin('base','lolim',lolim);
assignin('base','inflow',inflow);
assignin('base','outflow',outflow);
assignin('base','area',area);

%clear out primary data vectors
assignin('base','tout',[]);
assignin('base','tankheight',[]);
assignin('base','Outvalve',[]);
assignin('base','invalve',[]);
assignin('base','flushpulse',[]);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function h=locinitbuttons(hilim, lolim, inflow, outflow, area)

figs(1) = locgetfig(1);
delete(allchild(figs(1)))


%define button positioning parameters
width.edit = .07;
width.text = .20;
width.push = width.edit+width.text;
height.edit = .05;
height.text = height.edit;
height.push = .07;

pos.push.x=0.02;
pos.push.y=.6;
pos.edit.x=0.02;
pos.edit.y=.2;
pos.text.x=width.edit+.03;
pos.text.y=pos.edit.y;

color.bg = [.8 .8 .8];

%create pushbuttons

ui.all.Parent = figs(1);
ui.all.Units = 'Normalized';

ui.push = ui.all;
ui.push.BackgroundColor = color.bg;
ui.push.Style = 'pushbutton';

h.push.stop = uicontrol(ui.push, ...
    'String'    ,'ʼ'    , ...
    'Position', [pos.push.x pos.push.y+(3-1)*height.push ...
                 width.push height.push] , ...
    'Callback'  ,'watergui start');
h.push.flush = uicontrol(ui.push, ...
    'String'    ,'ˮ'        , ...
    'Enable'    ,'off'        , ...
    'Position', [pos.push.x pos.push.y+(2-1)*height.push ...
                 width.push height.push], ...
    'Callback'  ,'watergui flush');
h.push.close=uicontrol(ui.push, ...
    'String'    ,'رͼ'     , ...
    'Position', [pos.push.x pos.push.y+(1-1)*height.push ...
                 width.push height.push] , ...
    'Callback'  ,'watergui close');

if isempty(findobj(0,...
      'type','figure',...
      'Tag','fig 2',...
      'Visible','on'))
  set(h.push.close,'Enable','off')
end

%create edit and text buttons
ui.edit = ui.all;
ui.edit.Style = 'edit';
ui.edit.BackgroundColor = 'white';
ui.edit.Callback = 'watergui update';

ui.text = ui.all;
ui.text.Style='text';
ui.text.BackgroundColor = color.bg;
ui.text.HorizontalAlignment = 'left';

tags = {'inflow';'outflow';'lolim';'hilim';'area'};
tstring = { 'ˮ'      ; ...
            'ˮ'      ; ...
            'С߶'  ; ...
            '߶'  ; ...
            'Χ'};

siz = size(tags,1);
for i=siz:-1:1
  h.edit(i)=uicontrol(ui.edit,...
              'Tag',tags{i}                        ,...
              'String',eval(sprintf('num2str(%s)',tags{i}))  ,...
              'Position', [pos.edit.x pos.edit.y+(i-1)*height.edit...
                           width.edit height.edit]);
  h.text(i)=uicontrol(ui.text, ...
              'String',tstring(i)  , ...
              'Position', [pos.text.x ...
                           pos.text.y+(i-1)*height.text ...
                           width.text height.text] ...
              );
end

h.text(siz+1) = uicontrol(ui.text, ...
                          'FontSize',20     , ...
                          'FontWeight','bold', ...
                          'String','ʼť',...
                          'Units','Normalized',...
                          'Position',[.01 .01 .95 .08] ...
                          );


set(figs(1),'UserData',h,'visible','on')

%END FUNCTION create buttons

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function g=locdrawwater(hilim, lolim, inflow, outflow, area)

%set up the background graphics/lines for the water

figs(1) = locgetfig(1);

openaxes=findobj(figs(1),'type','axes');

if isempty(openaxes)
  ax=axes;
else
  delete(openaxes(2:end))
  ax=openaxes(1);
end

delete(get(ax,'children'))

edge=sqrt(area);
outwidth = sqrt(outflow)/pi;
inwidth = sqrt(inflow)/pi;
len=max(1,max(edge,hilim)/5);
top=1.25*max(hilim, lolim+outwidth);
ref.a = (edge/2-inwidth/2);
ref.b = ref.a+inwidth;
ref.c = ref.a-len/2;
ref.d = top+2*len+inwidth;

set(ax,'Position'  ,[.2 .1 .9 .9]    , ...
       'Visible'  ,'off'              , ...
       'Tag'      ,'picture'          , ...
       'DataAspectRatio',[1 1 1]      , ...
       'Parent'    , figs(1)          , ...
       'DrawMode'  ,'fast'              ...
       );

hg.all.parent = ax;
hg.all.erasemode = 'xor';


maintank.x = [0 edge edge 0 0];
maintank.y = [0 0 top top 0];

%DRAW LINES

in.horiz.x=[-len  ref.a ref.a -len -len];
in.horiz.y=[top+2*len top+2*len top+2*len+inwidth top+2*len+inwidth...
            top+2*len];
in.vert.x=[ref.a ref.b ref.b ref.a ref.a];
in.vert.y=[top+len top+len top+2*len+inwidth top+2*len+inwidth top+len];

out.horiz.x=[edge edge+len edge+len edge edge];
out.horiz.y=[lolim lolim lolim+outwidth lolim+outwidth lolim];
out.vert.x=[edge+len edge+len+outwidth edge+len+outwidth edge+len edge+len];
out.vert.y=[-len -len lolim+outwidth lolim+outwidth -len];

hg.line = hg.all;
hg.line.LineWidth = 3;
hg.line.Color = 'black';
hg.line.Marker = '.';
hg.line.MarkerEdgeColor = 'black';
hg.line.MarkerFaceColor = 'black';
hg.line.MarkerSize = 2;

g.line.tank =     line(maintank.x,maintank.y,hg.line);
g.line.invert =   line(in.vert.x,in.vert.y,hg.line);
g.line.inhoriz =   line(in.horiz.x,in.horiz.y,hg.line);
g.line.outvert =   line(out.vert.x,out.vert.y,hg.line);
g.line.outhoriz = line(out.horiz.x,out.horiz.y,hg.line);

%Make valves

oncolor=-.5;
offcolor=-.9;

in.valve.x=[ref.c  ref.a ref.a ref.c ref.c];
in.open.y = [ref.d ref.d ref.d+inwidth ref.d+inwidth ref.d];
out.valve.x=[edge+len/2 edge+len edge+len edge+len/2 edge+len/2];
out.open.y = [lolim+1*outwidth lolim+1*outwidth lolim+2*outwidth ...
              lolim+2*outwidth lolim+1*outwidth];


hg.valve = hg.all;
hg.valve.EdgeColor = 'black';

g.valve.in.off=patch(in.valve.x,in.horiz.y,offcolor,...
    'Tag','In Valve - Closed',hg.valve);
g.valve.in.on=patch(in.valve.x,in.open.y,oncolor,...
    'Tag','In Valve - Open',hg.valve);
g.valve.out.off=patch(out.valve.x,out.horiz.y,offcolor,...
    'Tag','Out Valve - Closed',hg.valve);
g.valve.out.on=patch(out.valve.x,out.open.y,oncolor,...
    'Tag','Out Valve - Open',hg.valve);

%Make drip-indicators

lin.x(1,1:4) = [-.45 -.35 -.25 -.35];
lin.x(2,1:4) = [-.25 -.15 -.05 -.15];
lin.x(3,1:4) = [-.05 .05 .025 -.025];
lin.x(4,1:4) = -lin.x(1,1:4);
lin.x(5,1:4) = -lin.x(2,1:4);

lin.y(1,1:4) = [-.9 -.9 -.1 -.1];
lin.y(2,1:4) = [-.9 -.9 -.5 -.5];

tdrip.x = lin.x*inwidth+edge/2;
tdrip.y = lin.y*len+top+len;

wc = -1.5;      % water color
bc = [.8 .8 .8];           % background color
hg.drip = hg.all;
hg.drip.EdgeColor = 'none';


tdrip2.x = lin.x*outwidth+edge+len+outwidth/2;
tdrip2.y = lin.y*len-len;

trans = [1 1 2 1 1];  %indicates which tdrip.y to use in for loop

for j=5:-1:1
  g.drip.in(j) = patch(tdrip.x(j,1:4), tdrip.y(trans(j),1:4),wc,hg.drip);
  g.drip.out(j) = patch(tdrip2.x(j,1:4), tdrip2.y(trans(j),1:4),wc,hg.drip);
end


%Make water level patches

z1 = [1 1 1 1 1];
zn1 = [-1 -1 -1 -1 -1];
firsty=mean(hilim,lolim);

mp.x= maintank.x;
mp.y = [0 0 firsty firsty 0];
gp.y = [firsty firsty top top firsty];

firsty=min(lolim+outwidth,firsty);

op.x = out.horiz.x;
op.y=[lolim lolim firsty firsty lolim];
gp.y=[firsty firsty lolim+outwidth lolim+outwidth firsty];
op.y2=[-len -len firsty firsty -len];
gp.y2=[firsty firsty lolim+outwidth lolim+outwidth firsty];

hg.water = hg.all;
hg.water.EdgeColor = 'none';
hg.water.EraseMode = 'none';

g.grey.main = patch(mp.x,gp.y,zn1,bc,hg.water);
g.water.main = patch(mp.x,mp.y,z1,wc,hg.water);

g.grey.outh = patch(op.x,gp.y,zn1,bc,hg.water);
g.water.outh = patch(op.x,op.y,z1,wc,hg.water);

g.grey.outv = patch(out.vert.x,gp.y2,zn1,bc,hg.water);
g.water.outv = patch(out.vert.x,op.y2,z1,wc,hg.water);

g.grey.inv = patch(in.vert.x,[-len -len -len -len -len], zn1, bc, hg.water);
g.water.inv = patch(in.vert.x,in.vert.y,z1,wc,hg.water);

g.water.inh = patch(in.horiz.x,in.horiz.y,z1,wc,hg.water);

%Final visual bits

set(ax,'UserData',g,...
    'XLim'    ,[-2*len edge+2*len+outwidth]  , ...
    'YLim'    ,[-3*len top+3*len+inwidth])

set(figs(1),'visible','on','backingstore','on');
drawnow
set(figs(1),'backingstore','off');
%END FUNCTION locdrawwater

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function locfinalplot

tout=evalin('base','tout');

tankheight=evalin('base','tankheight');
Outvalve=evalin('base','Outvalve');
invalve=evalin('base','invalve');
flushpulse=evalin('base','flushpulse');

if isempty(tankheight) | isempty(Outvalve)...
      | isempty(invalve) | isempty(flushpulse)
  loccloseplot
  return
end

hilim=evalin('base','hilim');
lolim=evalin('base','lolim');

figs(1) = locgetfig(1);
h=get(figs(1),'UserData');
set(h.push.close,'Enable','on')

figs(2) = locgetfig(2);

figure(figs(2))
clf
%delete(findobj(get(figs(2),'Children','flat','HandleVisibility','on')));

maxy=[11 1.1 1.1 1.1];

axname.y = {'Water Height';'Out Valve';'In Valve';'Flush'};
axname.x = {'';'';'';'Elapsed Time (sec)'};

if length(tout)~=length(tankheight)
  tout=1:length(tankheight);
  axname.x{4}='Simulation Step';
end
lastime=max(tout);


hg.ax.Xgrid = 'on';
hg.ax.Parent = figs(2);
hg.ax.XLim = [0 lastime];


for i=4:-1:1
  ax(i)=axes(hg.ax,...
             'Position', [.15 .1+.2*(4-i) .8 .15],...
             'YLim',[0 maxy(i)]);
  ylabel(axname.y(i))
  xlabel(axname.x(i))
end

set(ax(2:3),'Ytick',[0 1],'Yticklabel',{'off','on'});
set(ax(4),'Ytick',[0 1],'Yticklabel',{'',''});

h.height = line(tout,tankheight,'color','blue','parent',ax(1));
h.hilim = line([0 lastime],[hilim hilim],'color','cyan','parent',ax(1));
h.lolim = line([0 lastime],[lolim lolim],'color','cyan','parent',ax(1));

h.Outvalve = line(tout,Outvalve,'color','red','parent',ax(2));
h.invalve = line(tout,invalve,'color','green','parent',ax(3));
h.flushpulse = line(tout,flushpulse,'color','yellow','parent',ax(4));

title('Plumbing Simulation')

set(figs(2),'visible','on')

%tankpulse=tankheight(logical(flushpulse));
%timepulse=tout(logical(flushpulse));
%plot(timepulse,tankpulse,'b*')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function locflushme

oldDirty=get_param('water','Dirty');

if strcmp(get_param('water','simulationstatus'),'stopped')
   watergui('start');
end

fname = 'watersfun';
a = which(fname);
a = a(1:end-length(fname)-2);

if strncmpi(computer,'PC',2)
   try
      [noise,fs,bits]=wavread(fullfile(a,'private','water.wav'));
      sound(noise,fs,bits);
   end
end



a=1-str2num(get_param('water/Flush Pulse/PulseConst','value'));
set_param('water/Flush Pulse/PulseConst','value',num2str(a));
set_param('water','Dirty',oldDirty);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function loccloseplot
%this function closes the post-run plot

figs(2) = locgetfig(2);
figs(1) = locgetfig(1);

h=get(figs(1),'UserData');
set(h.push.close,'Enable','off')
set(figs(2),'Visible','off')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function figs=LocInitFigs

for i=1:2
  figs(i) = locgetfig(i);
  if figs(i)==0
    figs(i)=LocMakeFig(i);
  end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function fig=locgetfig(num)

tagstring = sprintf('fig %i',num);
openfigs=findobj(0,'type','figure','Tag',tagstring);
if isempty(openfigs)
  fig = 0;
else
  fig=openfigs(1);
  delete(openfigs(2:end))
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function handle=LocMakeFig(num)

tagstring = sprintf('fig %i',num);
crf={'watergui done'
    'watergui close'};
figname={'water Model GUI'
    'Post-Run Summary'};

handle=figure('Visible','off',...
              'Tag',tagstring,...
              'BackingStore','off',....
              'NumberTitle','off',...
              'Visible','off',...
              'Name',figname{num},...
              'CloseRequestFcn',crf{num},...
              'MenuBar','none');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function locdone
%run this function upon closing the simulink model as closefcn
%also run this if the "close" box of Fig 1 is clicked

figs(2) = locgetfig(2);

if figs(2)~=0
  delete(figs(2))
end


figs(1) = locgetfig(1);
if figs(1)~=0
  h = get(figs(1),'UserData');
  mystring = get(h.push.stop,'String');
  if mystring(1:4) == 'stop'
    set_param('water','simulationcommand','stop')
    set(h.push.stop,'String','ʼ')
    %watergui stop
  end
   
  delete(figs(1))
end


